cellsym

Function cellsym 

pub fn cellsym(idx: u8) -> String
Convenience function for block 0 (backward compatible).

Returns a cellsym string by index in block 0. unicode: U+F0000 ~ U+F00FF (Supplementary Private Use Area-A)

Using Supplementary PUA-A ensures no conflict with standard Unicode characters, including BMP PUA (U+E000-U+F8FF) used by NerdFont/Powerline.