Module sprite

Module sprite 

Sprite further encapsulates Buffer. It is also the most common component in RustPixel. It provides drawing methods such as set_border, draw_line, draw_circle. Refer to util/shape.rs for an example of how to draw a line.

Re-exports

pub use crate::render::buffer::SYMBOL_LINE;
pub use crate::render::buffer::Borders;
pub use crate::render::buffer::BorderType;

Structs

Layer
A Layer contains a set of Sprites stored in a vector. Sprites can be accessed via offset in the vector or by tag in the hashmap.
Sprite
Sprite: A positioned drawable element with dual coordinate semantics.

Traits

Widget