Layer

Struct Layer 

pub struct Layer {
    pub name: String,
    pub is_hidden: bool,
    pub sprites: Vec<Sprite>,
    pub tag_index: HashMap<String, usize>,
    pub render_index: Vec<(usize, i32)>,
    pub render_weight: i32,
}
A Layer contains a set of Sprites stored in a vector. Sprites can be accessed via offset in the vector or by tag in the hashmap.

Fields

name: Stringis_hidden: boolsprites: Vec<Sprite>tag_index: HashMap<String, usize>render_index: Vec<(usize, i32)>render_weight: i32

Implementations

Source

impl Layer

pub fn new(name: &str) -> Self

pub fn active(&mut self)

pub fn deactive(&mut self)

pub fn get_max_size(&self) -> PointU16

pub fn add(&mut self, ts: Sprite, tag: &str)

pub fn add_auto(&mut self, ts: Sprite)

Add sprite with auto-generated tag (for backward compatibility)

pub fn get(&mut self, name: &str) -> &mut Sprite

pub fn with_sprites<F, R>(&mut self, tags: &[&str], f: F) -> R
where F: FnOnce(&mut [&mut Sprite]) -> R,

Execute a closure with multiple sprites simultaneously

This method allows you to work with multiple sprites at once. Panics if any tags are duplicated.

Safety

Uses unsafe code internally but ensures safety by checking for duplicate indices.

pub fn get_immut(&self, name: &str) -> &Sprite

pub fn set_weight(&mut self, name: &str, w: i32)

pub fn set_hidden(&mut self, name: &str, hidden: bool)

pub fn update_render_index(&mut self)

pub fn render_all_to_buffer( &mut self, am: &mut AssetManager, buffer: &mut Buffer, )

Render all sprites to buffer by merging their content Scene::draw controls which layers should call this method